@@ -6,11 +6,11 @@ DBIx::Schema::Changelog::Action::View - Handles view actions
 
 =head1 VERSION
 
-Version 0.2.1
+Version 0.3.0
 
 =cut
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.3.0';
 
 use strict;
 use warnings;
@@ -30,12 +30,14 @@ with 'DBIx::Schema::Changelog::Action';
 
 sub add {
     my ( $self, $params ) = @_;
-    my $commands = $self->driver()->commands;
-    unless ( $commands->{create_view} ) {
-        print STDERR __PACKAGE__, " (", __LINE__, ") Create view is not supported!  ", $/;
+    my $actions = $self->driver()->actions;
+    unless ( $actions->{create_view} ) {
+        print STDERR __PACKAGE__, " (", __LINE__,
+          ") Create view is not supported!  ", $/;
         return;
     }
-    my $sql = _replace_spare( $commands->{create_view}, [ $params->{name}, $params->{as} ] );
+    my $sql = _replace_spare( $actions->{create_view},
+        [ $params->{name}, $params->{as} ] );
     $self->_do($sql);
 }
 
@@ -59,8 +61,8 @@ sub alter {
 
 sub drop {
     my ( $self, $params ) = @_;
-    my $commands = $self->driver()->commands;
-    my $sql = _replace_spare( $commands->{drop_view}, [ $params->{name} ] );
+    my $actions = $self->driver()->actions;
+    my $sql = _replace_spare( $actions->{drop_view}, [ $params->{name} ] );
     $self->_do($sql);
 
 }
